.sd-text-justify {
  text-align: justify !important;
}

.sd-text-left {
  text-align: left !important;
}

.sd-text-right {
  text-align: right !important;
}

.sd-text-center {
  text-align: center !important;
}

.sd-font-weight-light {
  font-weight: 300 !important;
}

.sd-font-weight-lighter {
  font-weight: lighter !important;
}

.sd-font-weight-normal {
  font-weight: 400 !important;
}

.sd-font-weight-bold {
  font-weight: 700 !important;
}

.sd-font-weight-bolder {
  font-weight: bolder !important;
}

.sd-font-italic {
  font-style: italic !important;
}

.sd-text-decoration-none {
  text-decoration: none !important;
}

.sd-text-lowercase {
  text-transform: lowercase !important;
}

.sd-text-uppercase {
  text-transform: uppercase !important;
}

.sd-text-capitalize {
  text-transform: capitalize !important;
}

.sd-text-wrap {
  white-space: normal !important;
}

.sd-text-nowrap {
  white-space: nowrap !important;
}

// requires `display: inline-block` or `display: block`
.sd-text-truncate {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

$font-sizes: (
  1: calc(1.375rem + 1.5vw),
  2: calc(1.325rem + 0.9vw),
  3: calc(1.3rem + 0.6vw),
  4: calc(1.275rem + 0.3vw),
  5: 1.25rem,
  6: 1rem
);

@each $id, $value in $font-sizes {
  .sd-fs-#{$id}, .sd-fs-#{$id} > p {
    font-size: $value !important;
    line-height: unset !important;
  }
}
