// Overrides for non-bootstrap themes (such as alabaster)

.sd-sphinx-override,
.sd-sphinx-override * {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
}

.sd-sphinx-override p {
  margin-top: 0;
}
