// Width and height

$sizes: (
  25: 25%,
  50: 50%,
  75: 75%,
  100: 100%,
  auto: auto,
);

@each $prop, $abbrev in (width: w, height: h) {
  @each $size, $length in $sizes {
    .sd-#{$abbrev}-#{$size} {
      #{$prop}: $length !important;
    }
  }
}
