// Adapted from Bootstrap v5.0.2 (https://getbootstrap.com/)
// Copyright 2011-2019 The Bootstrap Authors
// Copyright 2011-2019 Twitter, Inc.
// Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)

.sd-badge {
  display: inline-block;
  padding: 0.35em 0.65em;
  font-size: 0.75em;
  font-weight: 700;
  line-height: 1;
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: 0.25rem;

  // Empty badges collapse automatically
  &:empty {
    display: none;
  }
}

// Remove underline
a.sd-badge {
  text-decoration: none;
}

// Quick fix for badges in buttons
.sd-btn .sd-badge {
  position: relative;
  top: -1px;
}

// note badge colors were removed in v5
